﻿using System.Linq;
using System.Windows;
using System.Windows.Controls;
using Infragistics.Controls.Grids;

namespace XGrid
{
    public partial class MainPage : UserControl
    {
        #region Members

        private bool _hasSelectedRows = false;
        private bool _hasSelectedCells = false;

        #endregion // Members

        #region Constructor

        public MainPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
            this.xamGrid.SelectedCellsCollectionChanged += this.XamGridSelectedCellsCollectionChanged;
            this.xamGrid.SelectedRowsCollectionChanged += this.XamGridSelectedRowsCollectionChanged;
            this.xamGrid.ClipboardCopying += this.XamGridClipboardCopying;
        }

        private void XamGridClipboardCopying(object sender, ClipboardCopyingEventArgs e)
        {
            if (this._hasSelectedCells && this._hasSelectedRows)
            {
                MessageBox.Show("The command cannot be used on multiple selections.");
                e.Cancel = true;
            }
        }

        #endregion // Constructor

        #region Methods

        private void SetClipboardSetting()
        {
            if (this._hasSelectedCells)
            {
                this.xamGrid.ClipboardSettings.CopyType = GridClipboardCopyType.SelectedCells;
            }

            // In this case, cell selection has greater priority than row selection
            if (!this._hasSelectedCells && this._hasSelectedRows)
            {
                this.xamGrid.ClipboardSettings.CopyType = GridClipboardCopyType.SelectedRows;
            }
        }

        #endregion // Methods

        #region EventHandlers

        private void XamGridSelectedRowsCollectionChanged(object sender, SelectionCollectionChangedEventArgs<SelectedRowsCollection> e)
        {
            this._hasSelectedRows = e.NewSelectedItems.Any();

            this.SetClipboardSetting();
        }

        private void XamGridSelectedCellsCollectionChanged(object sender, SelectionCollectionChangedEventArgs<SelectedCellsCollection> e)
        {
            this._hasSelectedCells = e.NewSelectedItems.Any();

            this.SetClipboardSetting();
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            this.xamGrid.ItemsSource = new DataSource(50);
        }

        #endregion // EventHandlers
    }
}